@@ -209,18 +209,19 @@ func loadFromFile(file string) (string, error) {
 
 func checkSortDirection(mode string) error {
 	switch mode {
-	case "":
-		fallthrough
-	case "asc":
-		fallthrough
-	case "desc":
+	case "", "asc", "desc":
 		return nil
+	default:
+		return ErrInvalidSortDirection
 	}
-	return ErrInvalidSortDirection
 }
 
 func buildChangelog(ctx *context.Context) ([]string, error) {
-	log, err := getChangelog(ctx, ctx.Git.CurrentTag)
+	l, err := getChangeloger(ctx)
+	if err != nil {
+		return nil, err
+	}
+	log, err := l.Log(ctx)
 	if err != nil {
 		return nil, err
 	}
@@ -280,27 +281,6 @@ func extractCommitInfo(line string) string {
 	return strings.Join(strings.Split(line, " ")[1:], " ")
 }
 
-func getChangelog(ctx *context.Context, tag string) (string, error) {
-	prev := ctx.Git.PreviousTag
-	if prev == "" {
-		// get first commit
-		result, err := git.Clean(git.Run(ctx, "rev-list", "--max-parents=0", "HEAD"))
-		if err != nil {
-			return "", err
-		}
-		prev = result
-	}
-	return doGetChangelog(ctx, prev, tag)
-}
-
-func doGetChangelog(ctx *context.Context, prev, tag string) (string, error) {
-	l, err := getChangeloger(ctx)
-	if err != nil {
-		return "", err
-	}
-	return l.Log(ctx, prev, tag)
-}
-
 func getChangeloger(ctx *context.Context) (changeloger, error) {
 	switch ctx.Config.Changelog.Use {
 	case useGit:
@@ -387,19 +367,20 @@ func loadContent(ctx *context.Context, fileName, tmplName string) (string, error
 }
 
 type changeloger interface {
-	Log(ctx *context.Context, prev, current string) (string, error)
+	Log(ctx *context.Context) (string, error)
 }
 
 type gitChangeloger struct{}
 
 var validSHA1 = regexp.MustCompile(`^[a-fA-F0-9]{40}$`)
 
-func (g gitChangeloger) Log(ctx *context.Context, prev, current string) (string, error) {
+func (g gitChangeloger) Log(ctx *context.Context) (string, error) {
 	args := []string{"log", "--pretty=oneline", "--abbrev-commit", "--no-decorate", "--no-color"}
+	prev, current := comparePair(ctx)
 	if validSHA1.MatchString(prev) {
 		args = append(args, prev, current)
 	} else {
-		args = append(args, fmt.Sprintf("tags/%s..tags/%s", prev, current))
+		args = append(args, fmt.Sprintf("tags/%s..tags/%s", ctx.Git.PreviousTag, ctx.Git.CurrentTag))
 	}
 	return git.Run(ctx, args...)
 }
@@ -409,7 +390,8 @@ type scmChangeloger struct {
 	repo   client.Repo
 }
 
-func (c *scmChangeloger) Log(ctx *context.Context, prev, current string) (string, error) {
+func (c *scmChangeloger) Log(ctx *context.Context) (string, error) {
+	prev, current := comparePair(ctx)
 	return c.client.Changelog(ctx, c.repo, prev, current)
 }
 
@@ -418,6 +400,15 @@ type githubNativeChangeloger struct {
 	repo   client.Repo
 }
 
-func (c *githubNativeChangeloger) Log(ctx *context.Context, prev, current string) (string, error) {
-	return c.client.GenerateReleaseNotes(ctx, c.repo, prev, current)
+func (c *githubNativeChangeloger) Log(ctx *context.Context) (string, error) {
+	return c.client.GenerateReleaseNotes(ctx, c.repo, ctx.Git.PreviousTag, ctx.Git.CurrentTag)
+}
+
+func comparePair(ctx *context.Context) (prev string, current string) {
+	prev = ctx.Git.PreviousTag
+	current = ctx.Git.CurrentTag
+	if prev == "" {
+		prev = ctx.Git.FirstCommit
+	}
+	return
 }
